//==============================================================
//	Nom Programme	: minisumo.h
//	Date		: 10-06-2004
//	Version		: 1.0
//	Auteur		: F. Giamarchi
//
//	Description	: dfinitions des caractristiques
//			 du robot SUMO pour PIC 16F84	
//
//==============================================================
//	Configuration du microcontrleur
//==============================================================
#fuses	XT,NOPROTECT,NOWDT		// Dfinitions des fusibles
#use	delay(clock=4000000)		// Frquence du quartz
#define	Text	'S','U','M','O',' ','1','.','0'
#use	fixed_io(b_outputs=pin_B3, pin_B5, pin_B6)
//#use	fixed_io(a_outputs=pin_A2)	// ne pas valider cette option

#Bit	Del_jaune = 0x05.4	// Del verte sur broche RA4
#Bit	Bout_ma = 0x05.4	// Poussoir sur broche RA4

#Bit	Piezo = 0x06.6		// haut parleur Piezo sur RB6

#Bit	Vit_Ga = 0x05.0		// Vitesse du Moteur Gauche sur RA0
#Bit	Vit_Dr = 0x05.1		// Vitesse du Moteur Droit sur RA1
#Bit	Sens_Dr = 0x05.2	// Sens du Moteur droit sur RA2
#Bit	Sens_Ga = 0x05.3	// Sens du Moteur gauche sur RA3

#Bit	Bord_Dr = 0x06.1 	// Capteur de ligne droit sur RB1
#Bit	Bord_Ga = 0x06.2 	// Capteur de ligne gauche sur RB2

#Bit 	Ir_Dr = 0x06.3		// Emission Ir droit sur RB3
#Bit 	Ir_Ga  = 0x06.5 	// Emission Ir gauche sur RB5
#Bit 	Ir_Rec = 0x06.4  	// Reception Ir sur RB4
#Bit 	Choc_1 = 0x06.0  	// Pare-Choc n1 sur RB0
#Bit 	Choc_2 = 0x06.7		// Pare-Choc n2 sur RB7
//==============================================================
//	Dfinitions des constantes
//==============================================================
#Define	Arret	0x01
#Define	Avance	0x02
#Define	Recule	0x03
#Define	Droite	0x04
#Define	Gauche	0x05
#Define	Blocage	0x06

#Define	stop	0
#Define	Av	1
#Define	Ar	2

#Define	Non	1
#Define	Centre	2
#Define	A_Droite	3
#Define	A_Gauche	4

//==========================================================
//	Dclaration les variables globales
//==============================================================
short	Del_Etat, Piezo_Etat, Piezo_On, Ir_Dr_Valid, Ir_Dr_E, Ir_Ga_E;
short	Mot_Dr_mli, Mot_Ga_mli, Del_Cli, Del_E;
long	Time, msec, sec;
int	MLI, MLI_Dr, MLI_Ga;
int	Bord_dohyo, Ir_Etat;
int	Ir_Dr_Compt, Ir_Ga_Compt, Ir;

//==============================================================
//	Routines pour les moteurs
//==============================================================
void	Moteur_Dr(int sens, int vitesse)
{
if (sens == stop)
	{
	Sens_Dr = 0;
	Vit_Dr = 0;
	Mot_Dr_mli = 0;
	}
else if (sens == Av)
	{
	Sens_Dr = 0;
	MLI_Dr = vitesse;
	Mot_Dr_mli = 1;
	
	}
else if (sens == Ar)
	{
	Sens_Dr = 1;
	MLI_Dr = vitesse;
	Mot_Dr_mli = 1;
	}
else
	{
	Sens_Dr = 0;
	Vit_Dr = 0;
	Mot_Dr_mli = 0;
	}
}

void	Moteur_Ga(int sens, int vitesse)
{
if (sens == stop)
	{
	Sens_Ga = 1;
	Vit_Ga = 0;
	Mot_Ga_mli = 0;
	}
else if (sens == Av)
	{
	Sens_Ga = 1;
	MLI_Ga = vitesse;
	Mot_Ga_mli = 1;
	}
else if (sens == Ar)
	{
	Sens_Ga = 0;
	MLI_Ga = vitesse;
	Mot_Ga_mli = 1;
	}
else
	{
	Sens_Ga = 1;
	Vit_Ga = 0;
	Mot_Ga_mli = 0;
	}
}
//==============================================================
void	Son_On()
{
	Piezo_On = 1;}
void	Son_Off()
{
	Piezo_On = 0;
	Piezo = 0;}
//==============================================================
void	Init_Sumo()
{
	#rom	0x2100 ={Text};
	set_tris_A(0b00000000);
	set_tris_B(0b10010111);

	Ir_Dr = 0;
	Ir_Ga = 0;
	Del_jaune = 1;

	msec = 0;
	sec = 0;
	Time = 0;
	Ir = 0;
	MLI = 0;
	Piezo = 0;

	Moteur_Dr(stop,0);
	Moteur_Ga(stop,0);
}
//==============================================================
void	Start()
{
	delay_ms (1000);
	Del_jaune = 0;
	Son_On();
	delay_ms (1000);
	Del_jaune = 1;
	Son_Off();
	delay_ms (100);		// pour ne pas ractiver la Del jaune

	while (Bout_ma)
	{}

	Son_On();
	delay_ms (100);
	Son_Off();
	Del_jaune = 0;
	delay_ms (4900);	// retard obligatoire avant attaque
}
//==============================================================
// En incrmentant i, la distance de dtection augmente
void	Salve_Ir()
{
int i;
Ir_Etat = Non;

if (Ir_Dr_Valid)
	{
	Ir_Dr_Valid = 0;
	Ir_Dr_E = 0;

	for (i=0; i<12; i++)
		{
		Ir_Dr = 1;
		delay_us(1);
		Ir_Dr = 0;
		delay_us(9);
		}

	if (!Ir_Rec)
		{
		Ir_Dr_Compt ++;
		if (Ir_Dr_Compt > 5)
			{
			Ir_Dr_Compt = 0;
			Ir_Dr_E = 1;
			}
		}
	}
else
	{
	Ir_Dr_Valid = 1;
	Ir_Ga_E = 0;

	for (i=0; i<12; i++)
		{
		Ir_Ga = 1;
		delay_us(1);
		Ir_Ga = 0;
		delay_us(9);
		}

	if (!Ir_Rec)
		{
		Ir_Ga_Compt ++;
		if (Ir_Ga_Compt > 5)
			{
			Ir_Ga_Compt = 0;
			Ir_Ga_E = 1;
			}
		}
	if (Ir_Dr_E && Ir_Ga_E)
		Ir_Etat = Centre;
	else if (Ir_Dr_E)
		Ir_Etat = A_Droite;
	else if (Ir_Ga_E)
		Ir_Etat = A_Gauche;
	else
		Ir_Etat = Non;
	}
}
//==============================================================
